/* Daily routine monitor Solder check for Arduino Mega */
/* CC BY-NC-SA Jeroen Brinkman */
/* Version 1 dd 29-12-2023 */

#include <Arduino.h>
#include <TM1637Display.h>
#include "EEPROM.h"

#define HEART    13     // blinking led showing the programma's hartbeat
#define D29      14     // Day 29 active
#define D30      15     // Day 30 active
#define D31      16     // Day 31 active
#define CLKW      4     // White display clock
#define DIOW      5     // White display data
#define CLKG      6     // Green display clock
#define DIOG      7     // Green display data

// Create display objects
TM1637Display displayW(CLKW, DIOW); // define white display
TM1637Display displayG(CLKG, DIOG); // define green display

int i, j;

//                    0, 1, 2, 3, 4, 5, 6, 7, 8, 9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31
const int days[32] = {0,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47}; // the pin number for the corresponding day switch
// Use this program to check and adapt the sequence of the above pin numbering.


void setup() {
  
/* ------- Setup -------  */

  /* define I/O  */
  pinMode(HEART, OUTPUT); // blinking led showing the programma's hartbeat
  pinMode(D29, OUTPUT);
  pinMode(D30, OUTPUT);
  pinMode(D31, OUTPUT);
  digitalWrite(D29, 0); 
  digitalWrite(D30, 0); 
  digitalWrite(D31, 0);
  for (i = 1; i < 32; i++) pinMode(days[i], INPUT_PULLUP); // define all day buttons

  uint8_t data[] = { 0xff, 0xff, 0xff, 0xff };
  uint8_t blank[] = { 0x00, 0x00, 0x00, 0x00 };
  displayW.setBrightness(0x0f);
  displayG.setBrightness(0x0f);

  // All segments on
  displayG.setSegments(data);
  displayW.setSegments(data);

 }

void loop() {
  digitalWrite(HEART, (millis() / 1000) % 2); //1s heartbeat for the onboard led
 
  /* read the day buttons */

  i = 1;
  while((digitalRead(days[i])) && (i < 32)) {
    i += 1;
  }
  j = days[i];
  if (i == 32) i = 0;
  if (i == 0) j = 0;
  displayW.showNumberDec(j, false); // display shows the day
  displayG.showNumberDec(i, false); // display shows the port

}